Learn R Programming

makicoint (version 1.0.0)

print.maki_test: Print Method for Maki Test Results

Description

Prints a formatted summary of the Maki cointegration test results, including test statistic, break points, critical values, and conclusions.

Usage

# S3 method for maki_test
print(x, ...)

Value

Returns the input object x invisibly. This function is called primarily for its side effect of printing formatted test results to the console.

Arguments

x

An object of class "maki_test" returned by coint_maki

...

Additional arguments (currently unused)